(function($) {
    'use strict';
    
    // Ellenőrizzük, hogy a felhasználó már feliratkozott-e
    function checkSubscriptionStatus() {
        var hasSubscribed = localStorage.getItem("hasAlreadySubscribed");
        
        if (hasSubscribed === "true") {
            return;
        }
        
        // Ellenőrizzük, hogy az űrlap el lett-e utasítva
        var formDismissedUntil = localStorage.getItem("subscribeFormDismissedUntil");
        var currentTime = new Date().getTime();
        
        if (!formDismissedUntil || currentTime > parseInt(formDismissedUntil)) {
            // 10 másodperc múlva megjelenítjük a popup-ot
            setTimeout(function() {
                showSubscriptionPopup();
            }, 10000);
        }
    }
    
    // Popup megjelenítése
    function showSubscriptionPopup() {
        // Ha már létezik, ne jelenítsük meg újra
        if ($('#newsletter-overlay').length) {
            return;
        }
        
        // Szövegek lekérése AJAX-szal
        $.ajax({
            url: newsletterData.ajaxurl,
            type: 'POST',
            data: {
                action: 'hirlevel_get_texts',
                nonce: newsletterData.nonce
            },
            success: function(response) {
                if (response.success) {
                    createPopup(response.data);
                }
            },
            error: function() {
                console.error('Hiba a szövegek betöltésekor');
            }
        });
    }
    
    // Popup létrehozása a szövegek alapján
    function createPopup(texts) {
        // Popup tartalom
        var popupHTML = 
            '<div id="newsletter-overlay" class="newsletter-overlay">' +
                '<div class="modal-container">' +
                    '<div class="form-container">' +
                        '<button class="close-button" aria-label="Bezárás">' +
                            '<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round">' +
                                '<line x1="18" y1="6" x2="6" y2="18"></line>' +
                                '<line x1="6" y1="6" x2="18" y2="18"></line>' +
                            '</svg>' +
                        '</button>' +
                        '<h2 class="form-title">' + texts.title + '</h2>' +
                        '<p class="form-subtitle">' + texts.subtitle + '</p>' +
                        '<div class="newsletter-form-content">' +
                            '<div class="input-group">' +
                                '<label for="popup-newsletter-email">' + texts.email_label + '</label>' +
                                '<div class="input-wrapper">' +
                                    '<input type="email" id="popup-newsletter-email" placeholder="emailcimed@example.com" required>' +
                                    '<svg class="email-icon" xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round">' +
                                        '<path d="M4 4h16c1.1 0 2 .9 2 2v12c0 1.1-.9 2-2 2H4c-1.1 0-2-.9-2-2V6c0-1.1.9-2 2-2z"></path>' +
                                        '<polyline points="22,6 12,13 2,6"></polyline>' +
                                    '</svg>' +
                                '</div>' +
                            '</div>' +
                            '<div class="terms-container">' +
                                '<div class="checkbox-wrapper">' +
                                    '<input type="checkbox" id="popup-newsletter-terms">' +
                                    '<label for="popup-newsletter-terms">' +
                                        texts.terms_text_with_link +
                                    '</label>' +
                                '</div>' +
                            '</div>' +
                            '<div class="status-message" style="display: none;"></div>' +
                            '<button type="button" id="popup-newsletter-submit">' + texts.button_text + '</button>' +
                            '<p class="privacy-note">' + texts.privacy_note + '</p>' +
                        '</div>' +
                    '</div>' +
                '</div>' +
            '</div>';
            
        $('body').append(popupHTML);
        
        // Bezárás gomb eseménykezelő
        $('#newsletter-overlay .close-button').click(function() {
            dismissForm();
        });
        
        // Feliratkozás gomb eseménykezelő
        $('#popup-newsletter-submit').click(function() {
            submitSubscription(true);
        });
    }
    
    // Form elküldése
    function submitSubscription(isPopup) {
        var prefix = isPopup ? 'popup-' : '';
        var email = $('#' + prefix + 'newsletter-email').val();
        var acceptedTerms = $('#' + prefix + 'newsletter-terms').is(':checked');
        var statusElement = isPopup ? 
            $('#newsletter-overlay .status-message') : 
            $('#hirlevel-feliratkozas-form .status-message');
        var submitButton = $('#' + prefix + 'newsletter-submit');
        
        // Visszaállítjuk az állapotot
        statusElement.hide().removeClass('success error');
        
        // Ellenőrzések
        if (!email) {
            showStatusMessage('error', 'Kérjük, add meg az email címedet!', statusElement);
            return;
        }
        
        if (!acceptedTerms) {
            showStatusMessage('error', 'Kérjük, fogadd el az adatkezelési tájékoztatót!', statusElement);
            return;
        }
        
        // Loading állapot
        var originalButtonText = submitButton.text();
        submitButton.text('Folyamatban...').prop('disabled', true);
        
        // AJAX kérés küldése
        $.ajax({
            url: newsletterData.ajaxurl,
            type: 'POST',
            data: {
                action: 'hirlevel_feliratkozas',
                nonce: newsletterData.nonce,
                email: email,
                accepted_terms: acceptedTerms
            },
            success: function(response) {
                if (response.success) {
                    showStatusMessage('success', response.data.message, statusElement);
                    $('#' + prefix + 'newsletter-email').val('');
                    $('#' + prefix + 'newsletter-terms').prop('checked', false);
                    
                    // Sikeres feliratkozás után mentjük a localStorage-ba
                    localStorage.setItem("hasAlreadySubscribed", "true");
                    
                    // 3 másodperc múlva bezárjuk, ha popup
                    if (isPopup) {
                        setTimeout(function() {
                            dismissForm();
                        }, 3000);
                    }
                } else {
                    showStatusMessage('error', response.data.message, statusElement);
                    
                    // Ha a hiba "már feliratkozott", akkor nem jelenítjük meg többet
                    if (response.data.message.includes('már fel van iratkozva') || 
                        response.data.message.includes('already subscribed')) {
                        localStorage.setItem("hasAlreadySubscribed", "true");
                        
                        // 3 másodperc múlva bezárjuk, ha popup
                        if (isPopup) {
                            setTimeout(function() {
                                dismissForm();
                            }, 3000);
                        }
                    }
                }
            },
            error: function() {
                showStatusMessage('error', 'Váratlan hiba történt. Kérjük, próbáld újra!', statusElement);
            },
            complete: function() {
                submitButton.text(originalButtonText).prop('disabled', false);
            }
        });
    }
    
    // Státusz üzenet megjelenítése
    function showStatusMessage(type, message, element) {
        element.removeClass('success error').addClass(type).html(message).fadeIn();
    }
    
    // Popup bezárása
    function dismissForm() {
        $('#newsletter-overlay').fadeOut(300, function() {
            $(this).remove();
        });
        
        // Ha nem sikeres feliratkozás után történt a bezárás
        if (localStorage.getItem("hasAlreadySubscribed") !== "true") {
            var oneWeekFromNow = new Date().getTime() + (7 * 24 * 60 * 60 * 1000);
            localStorage.setItem("subscribeFormDismissedUntil", oneWeekFromNow.toString());
        }
    }
    
    // Indítás amikor a dokumentum betöltődött
    $(document).ready(function() {
        // Ha van beágyazott űrlap (shortcode által)
        if ($('#hirlevel-feliratkozas-form').length) {
            // Eseménykezelők hozzáadása a beágyazott űrlapra
            $('#newsletter-submit').click(function() {
                submitSubscription(false);
            });
        }
        
        // Ellenőrizzük, hogy kell-e popup-ot megjeleníteni
        checkSubscriptionStatus();
    });
    
})(jQuery);