<?php
/**
 * Plugin Name: Hírlevél Feliratkozás
 * Plugin URI: https://selonsophie.hu
 * Description: API alapú hírlevél feliratkozás kezelése
 * Version: 1.0.3
 * Author: Selon Sophie
 * Author URI: https://selonsophie.hu
 * Text Domain: hirlevel-feliratkozas
 */

// Biztonsági ellenőrzés
if (!defined('ABSPATH')) {
    exit; // Közvetlen hozzáférés megakadályozása
}

// API végpont konstans (fix érték, nem szerkeszthető)
define('HIRLEVEL_API_ENDPOINT', 'https://www.hirlevelek-kuldese.hu/api/partnerSubscribe');

// Fájlok betöltése
require_once plugin_dir_path(__FILE__) . 'includes/admin-settings.php';
require_once plugin_dir_path(__FILE__) . 'includes/shortcodes.php';

// Script-ek és stílusok betöltése
function hirlevel_feliratkozas_enqueue_scripts() {
    wp_enqueue_style(
        'hirlevel-feliratkozas-style', 
        plugin_dir_url(__FILE__) . 'assets/css/newsletter-form.css',
        array(),
        '1.0.3'
    );
    
    wp_enqueue_script(
        'hirlevel-feliratkozas-script',
        plugin_dir_url(__FILE__) . 'assets/js/newsletter-form.js',
        array('jquery'),
        '1.0.3',
        true
    );
    
    // Adatok átadása a JavaScript számára
    wp_localize_script(
        'hirlevel-feliratkozas-script',
        'newsletterData',
        array(
            'ajaxurl' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('hirlevel_feliratkozas_nonce')
        )
    );
    
    // Admin oldalon a színválasztó script betöltése
    if (is_admin()) {
        wp_enqueue_style('wp-color-picker');
        wp_enqueue_script('wp-color-picker');
        wp_enqueue_script(
            'hirlevel-feliratkozas-admin-script',
            plugin_dir_url(__FILE__) . 'assets/js/admin-script.js',
            array('jquery', 'wp-color-picker'),
            '1.0.3',
            true
        );
    }
}
add_action('wp_enqueue_scripts', 'hirlevel_feliratkozas_enqueue_scripts');
add_action('admin_enqueue_scripts', 'hirlevel_feliratkozas_enqueue_scripts');

// Plugin aktiválásakor
function hirlevel_feliratkozas_activation() {
    // Alapértelmezett beállítások
    if (!get_option('hirlevel_feliratkozas_api_domain')) {
        update_option('hirlevel_feliratkozas_api_domain', site_url());
    }
    
    // Alapértelmezett stílus beállítások
    if (!get_option('hirlevel_feliratkozas_button_color')) {
        update_option('hirlevel_feliratkozas_button_color', '#403317');
    }
    
    if (!get_option('hirlevel_feliratkozas_text_color')) {
        update_option('hirlevel_feliratkozas_text_color', '#403317');
    }
    
    if (!get_option('hirlevel_feliratkozas_background_color')) {
        update_option('hirlevel_feliratkozas_background_color', '#fbfaf4');
    }
    
    if (!get_option('hirlevel_feliratkozas_form_width')) {
        update_option('hirlevel_feliratkozas_form_width', '500');
    }
    
    if (!get_option('hirlevel_feliratkozas_border_radius')) {
        update_option('hirlevel_feliratkozas_border_radius', '0');
    }
    
    // Alapértelmezett szövegek
    if (!get_option('hirlevel_feliratkozas_form_title')) {
        update_option('hirlevel_feliratkozas_form_title', 'Iratkozz fel hírlevelünkre');
    }
    
    if (!get_option('hirlevel_feliratkozas_form_subtitle')) {
        update_option('hirlevel_feliratkozas_form_subtitle', 'Értesülj az új cikkekről és exkluzív tartalmakról');
    }
    
    if (!get_option('hirlevel_feliratkozas_email_label')) {
        update_option('hirlevel_feliratkozas_email_label', 'Email cím');
    }
    
    if (!get_option('hirlevel_feliratkozas_terms_text')) {
        update_option('hirlevel_feliratkozas_terms_text', 'Elfogadom az adatkezelési tájékoztatót, és hozzájárulok a személyes adataim kezeléséhez.');
    }
    
    if (!get_option('hirlevel_feliratkozas_privacy_link')) {
        update_option('hirlevel_feliratkozas_privacy_link', site_url('/adatkezeles'));
    }
    
    if (!get_option('hirlevel_feliratkozas_button_text')) {
        update_option('hirlevel_feliratkozas_button_text', 'Feliratkozás');
    }
    
    if (!get_option('hirlevel_feliratkozas_privacy_note')) {
        update_option('hirlevel_feliratkozas_privacy_note', 'Tiszteletben tartjuk a magánéletedet. Bármikor leiratkozhatsz.');
    }
    
    if (!get_option('hirlevel_feliratkozas_success_message')) {
        update_option('hirlevel_feliratkozas_success_message', 'Sikeresen feliratkoztál!');
    }
}
register_activation_hook(__FILE__, 'hirlevel_feliratkozas_activation');

// Dinamikus CSS generálása a beállítások alapján
function hirlevel_feliratkozas_dynamic_css() {
    $button_color = get_option('hirlevel_feliratkozas_button_color', '#403317');
    $text_color = get_option('hirlevel_feliratkozas_text_color', '#403317');
    $background_color = get_option('hirlevel_feliratkozas_background_color', '#fbfaf4');
    $form_width = get_option('hirlevel_feliratkozas_form_width', '500');
    $border_radius = get_option('hirlevel_feliratkozas_border_radius', '0');
    $custom_css = get_option('hirlevel_feliratkozas_custom_css', '');
    
    $dynamic_css = "
        .newsletter-form, .form-container {
            background-color: {$background_color};
            color: {$text_color};
            max-width: {$form_width}px;
            border-radius: {$border_radius}px;
        }
        
        .form-title, .form-subtitle, .checkbox-wrapper label {
            color: {$text_color};
        }
        
        .input-wrapper input, .checkbox-wrapper input[type='checkbox'] {
            border-radius: {$border_radius}px;
        }
        
        button[id$='newsletter-submit'] {
            background-color: {$button_color};
            border-radius: {$border_radius}px;
        }
        
        button[id$='newsletter-submit']:hover {
            background-color: " . hirlevel_adjust_brightness($button_color, -20) . ";
        }
        
        .status-message {
            border-radius: {$border_radius}px;
        }
        
        {$custom_css}
    ";
    
    echo '<style type="text/css">' . $dynamic_css . '</style>';
}
add_action('wp_head', 'hirlevel_feliratkozas_dynamic_css');

// Segédfüggvény a szín árnyalásához
function hirlevel_adjust_brightness($hex, $steps) {
    // Konvertáljuk a hex színt RGB-re
    $hex = str_replace('#', '', $hex);
    
    $r = hexdec(substr($hex, 0, 2));
    $g = hexdec(substr($hex, 2, 2));
    $b = hexdec(substr($hex, 4, 2));
    
    // Módosítsuk a fényerőt
    $r = max(0, min(255, $r + $steps));
    $g = max(0, min(255, $g + $steps));
    $b = max(0, min(255, $b + $steps));
    
    // Konvertáljuk vissza hex-re
    return sprintf('#%02x%02x%02x', $r, $g, $b);
}